@@ -14,17 +14,15 @@ use strict;
 use warnings;
 
 package Pod::Markdown;
-# git description: v3.001-2-g6d52642
+# git description: v3.002-4-gfce44d9
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Convert POD to Markdown
-$Pod::Markdown::VERSION = '3.002';
-use Pod::Simple 3.26 (); # detected_encoding
+$Pod::Markdown::VERSION = '3.003';
+use Pod::Simple 3.27 (); # detected_encoding and keep_encoding bug fix
 use parent qw(Pod::Simple::Methody);
 use Encode ();
 
-my $NBSP = chr(0xA0);
-
 our %URL_PREFIXES = (
   sco      => 'http://search.cpan.org/perldoc?',
   metacpan => 'https://metacpan.org/pod/',
@@ -69,8 +67,9 @@ $URL_PREFIXES{perldoc} = $URL_PREFIXES{metacpan};
   # Add a few very common ones for consistency and readability
   # (in case HTML::Entities isn't available).
   %entities = (
-    $NBSP     => 'nbsp',
-    chr(0xA9) => 'copy',
+    # Pod::Markdown has always required 5.8 so unicode_to_native will be available.
+    chr(utf8::unicode_to_native(0xA0)) => 'nbsp',
+    chr(utf8::unicode_to_native(0xA9)) => 'copy',
     %entities
   );
 
@@ -110,6 +109,7 @@ sub new {
 
   my $self = $class->SUPER::new();
   $self->preserve_whitespace(1);
+  $self->nbsp_for_S(1);
   $self->accept_targets(qw( markdown html ));
 
   while( my ($attr, $val) = each %args ){
@@ -535,13 +535,6 @@ sub handle_text {
   my $stash = $self->_private;
   local $_  = $_[1];
 
-  # NOTE: If this document ends up forcing ascii encoding (which might not be known at this
-  # point) and this is a code block, these will get entity-encoded which will be
-  # wrong.  In order to solve that we might have to escape them like we do [&<]
-  # or simply ignore nbsp if no_escape.
-  s/ /$NBSP/g
-    if $stash->{nbsp};
-
   # Unless we're in a code span, verbatim block, or formatted region.
   unless( $stash->{no_escape} ){
 
@@ -929,9 +922,6 @@ sub   end_C {
 sub start_F { shift->start_C(@_); }
 sub   end_F { shift  ->end_C(@_); }
 
-sub start_S { $_[0]->_private->{nbsp}++; }
-sub   end_S { $_[0]->_private->{nbsp}--; }
-
 sub start_L {
   my ($self, $flags) = @_;
   $self->_new_stack;
@@ -1164,7 +1154,7 @@ Pod::Markdown - Convert POD to Markdown
 
 =head1 VERSION
 
-version 3.002
+version 3.003
 
 =head1 SYNOPSIS
 
